@@ -63,14 +63,13 @@ def dpwrspc(time, quantity, nboxpoints=256, nshiftpoints=128, binsize=3,
         window = np.hanning(nboxpoints)
 
     # remove NaNs from the data
-    where_finite = np.where(np.isnan(quantity)==False)
+    where_finite = np.where(np.isnan(quantity) == False)
 
     quantity2process = quantity[where_finite[0]]
     times2process = time[where_finite[0]]
     nboxpnts = nboxpoints
     nshiftpnts = nshiftpoints
 
-
     totalpoints = len(times2process)
     nspectra = int((totalpoints-nboxpnts/2.)/nshiftpnts)
 
@@ -115,23 +114,24 @@ def dpwrspc(time, quantity, nboxpoints=256, nshiftpoints=128, binsize=3,
                 line = poly1d_fn(t)
                 x = x - line
 
-
             if nohanning is False:
                 x = x*window
 
             bign = nboxpnts
 
             if bign % 2 != 0:
-                print('needs an even number of data points, dropping last point...')
+                print('dpwrspc: needs an even number of data points,\
+                      dropping last point...')
                 t = t[0:bign-1]
                 x = x[0:bign-1]
                 bign = bign - 1
 
             n_tm = len(t)
 
-            # time variance can break power spectrum, this keyword skips over those gaps
+            # time variance can break power spectrum
+            # this keyword skips over those gaps
             if notmvariance and n_tm > 1:
-                if tm_sensitivity != None:
+                if tm_sensitivity is not None:
                     tmsn = tm_sensitivity
                 else:
                     tmsn = 100.0
@@ -147,7 +147,8 @@ def dpwrspc(time, quantity, nboxpoints=256, nshiftpoints=128, binsize=3,
 
                     continue
 
-            # following Numerical recipes in Fortran, p. 421, sort of... (actually following the IDL implementation)
+            # following Numerical recipes in Fortran, p. 421, sort of...
+            # (actually following the IDL implementation)
             k = np.array(range(int(bign/2)+1))
             tres = np.median(t[1:len(t)] - t[0:len(t)-1])
             fk = k/(bign*tres)
@@ -156,7 +157,8 @@ def dpwrspc(time, quantity, nboxpoints=256, nshiftpoints=128, binsize=3,
 
             pwr = np.zeros(int(bign/2+1))
             pwr[0] = xs2[0]/bign**2
-            pwr[1:int(bign/2)] = (xs2[1:int(bign/2)] + xs2[bign-(1+np.array(range(int(bign/2-1))))])/bign**2
+            ptmp = (1+np.array(range(int(bign/2-1))))
+            pwr[1:int(bign/2)] = (xs2[1:int(bign/2)] + xs2[bign-ptmp])/bign**2
             pwr[int(bign/2)] = xs2[int(bign/2)]/bign**2
 
             if nohanning is False:
@@ -177,7 +179,7 @@ def dpwrspc(time, quantity, nboxpoints=256, nshiftpoints=128, binsize=3,
                 power = power+pwr[iarray*binsize+i+1]
 
             if notperhz is False:
-                power=power/dfreq
+                power = power/dfreq
 
             dps[nthspectrum, :] = power
             fdps[nthspectrum, :] = freqcenter
