@@ -1,12 +1,18 @@
+
+import logging
 import numpy as np
 from pytplot import get_data, store_data, options
 from ...utilities.tnames import tnames
 
-def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_units='flux', data_rate='srvy'):
+logging.captureWarnings(True)
+logging.basicConfig(format='%(asctime)s: %(message)s', datefmt='%d-%b-%y %H:%M:%S', level=logging.INFO)
+
+def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_units='flux', data_rate='srvy', level='l2'):
     """
     This function will calculate the omni-directional EIS spectrograms, and is automatically called from mms_load_eis
     
-    Parameters:
+    Parameters
+    ----------
         probe: str
             probe #, e.g., '4' for MMS4
 
@@ -25,6 +31,9 @@ def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_unit
         data_rate: str
             instrument data rate, e.g., 'srvy' or 'brst' (default: 'srvy')
 
+        level: str
+            data level ['l1a','l1b','l2pre','l2' (default)]
+
 
     Returns:
         Name of tplot variable created.
@@ -32,10 +41,7 @@ def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_unit
     
     probe = str(probe)
     species_str = datatype + '_' + species
-    if data_rate == 'brst':
-        prefix = 'mms' + probe + '_epd_eis_brst_'
-    else: 
-        prefix = 'mms' + probe + '_epd_eis_'
+    prefix = 'mms' + probe + '_epd_eis_' + data_rate + '_' + level + '_'
 
     if data_units == 'flux':
         units_label = '1/(cm^2-sr-s-keV)'
@@ -50,7 +56,7 @@ def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_unit
         scope_data = get_data(telescopes[0])
             
         if len(scope_data) <= 2:
-            print("Error, couldn't find energy table for the variable: " + telescopes[0])
+            logging.error("Error, couldn't find energy table for the variable: " + telescopes[0])
             return None
 
         time, data, energies = scope_data
@@ -65,9 +71,10 @@ def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_unit
         options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'ylog', 1)
         options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'zlog', 1)
         options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'ztitle', units_label)
-        options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'ytitle', 'MMS' + probe + ' ' + datatype + ' ' + species + ' Energy [keV]')
+        options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'ytitle', 'MMS' + probe + ' ' + datatype + ' ' + species)
+        options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'ysubtitle', 'Energy [keV]')
         options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'yrange', [14, 45])
-        options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'Colormap', 'jet')
+        options(prefix + species_str + '_' + data_units + '_omni' + suffix, 'Colormap', 'spedas')
 
         # create new variable with omni energy limits
         energy_minus = get_data(prefix + species_str + '_t0_energy_dminus' + suffix)
@@ -80,5 +87,5 @@ def mms_eis_omni(probe, species='proton', datatype='extof', suffix='', data_unit
 
         return prefix + species_str + '_' + data_units + '_omni' + suffix
     else:
-        print('Error, problem finding the telescopes to calculate omni-directional spectrograms')
+        logging.error('Error, problem finding the telescopes to calculate omni-directional spectrograms')
         return None
