@@ -4,6 +4,14 @@ import numpy as np
 import scipy 
 from pytplot import get_data, store_data, options
 
+# use nanmean from bottleneck if it's installed, otherwise use the numpy one
+# bottleneck nanmean is ~2.5x faster
+try:
+    import bottleneck as bn
+    nanmean = bn.nanmean
+except ImportError:
+    nanmean = np.nanmean
+
 def mms_feeps_pad_spinavg(probe='1', data_units='intensity', datatype='electron', data_rate='srvy', level='l2', suffix='', energy=[70, 600], bin_size=16.3636):
     """
     This function will spin-average the FEEPS pitch angle distributions
@@ -43,11 +51,6 @@ def mms_feeps_pad_spinavg(probe='1', data_units='intensity', datatype='electron'
     elif data_units == 'counts':
         units_label = '[counts/s]'
 
-    if datatype == 'electron':
-        lower_en = 71
-    else:
-        lower_en = 78
-
     prefix = 'mms'+str(probe)+'_epd_feeps_'
 
     n_pabins = 180./bin_size
@@ -75,7 +78,7 @@ def mms_feeps_pad_spinavg(probe='1', data_units='intensity', datatype='electron'
     for spin_idx in range(0, len(spin_starts)):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", category=RuntimeWarning)
-            spin_avg_flux[spin_idx, :] = np.nanmean(data[current_start:spin_starts[spin_idx]+1, :], axis=0)
+            spin_avg_flux[spin_idx, :] = nanmean(data[current_start:spin_starts[spin_idx]+1, :], axis=0)
             spin_times[spin_idx] = times[current_start]
 
             # rebin and interpolate to new_bins
@@ -95,8 +98,9 @@ def mms_feeps_pad_spinavg(probe='1', data_units='intensity', datatype='electron'
     options(var_name + '_spin' + suffix, 'spec', True)
     options(var_name + '_spin' + suffix, 'ylog', False)
     options(var_name + '_spin' + suffix, 'zlog', True)
-    options(var_name + '_spin' + suffix, 'Colormap', 'jet')
+    options(var_name + '_spin' + suffix, 'Colormap', 'spedas')
     options(var_name + '_spin' + suffix, 'ztitle', units_label)
-    options(var_name + '_spin' + suffix, 'ytitle', 'MMS' + str(probe) + ' ' + datatype + ' PA (deg)')
+    options(var_name + '_spin' + suffix, 'ytitle', 'MMS' + str(probe) + ' ' + datatype + ' PA')
+    options(var_name + '_spin' + suffix, 'ysubtitle', '[deg]')
 
     return var_name + '_spin' + suffix
