@@ -4,7 +4,8 @@ def mms_scm_set_metadata(tnames, probe, datatype, coord, suffix=''):
     """
     This function updates the metadata for the SCM data products
     
-    Parameters:
+    Parameters
+    ----------
         tnames : list of str
             list of tplot variables loaded by the load routine
 
@@ -33,12 +34,12 @@ def mms_scm_set_metadata(tnames, probe, datatype, coord, suffix=''):
         elif tvar == 'mms'+probe+'_scm_acb_'+coord+'_scsrvy_srvy_l2'+suffix:
             options(tvar, 'color', ['b', 'g', 'r'])
             options(tvar, 'legend_names', ['Bx', 'By', 'Bz'])
-            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype+' [nT]')
+            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype)
         elif tvar == 'mms'+probe+'_scm_acb_'+coord+'_scb_brst_l2'+suffix:
             options(tvar, 'color', ['b', 'g', 'r'])
             options(tvar, 'legend_names', ['Bx', 'By', 'Bz'])
-            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype+' [nT]')
+            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype)
         elif tvar == 'mms'+probe+'_scm_acb_'+coord+'_schb_brst_l2'+suffix:
             options(tvar, 'color', ['b', 'g', 'r'])
             options(tvar, 'legend_names', ['Bx', 'By', 'Bz'])
-            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype+' [nT]')
+            options(tvar, 'ytitle', 'MMS'+probe+' SCM '+datatype)
