@@ -5,6 +5,8 @@ from pyspedas.mms import mms_load_state, mms_load_mec, mms_load_fgm, mms_load_sc
 from pyspedas.utilities.data_exists import data_exists
 from pyspedas.mms.hpca.mms_hpca_calc_anodes import mms_hpca_calc_anodes
 from pyspedas.mms.hpca.mms_hpca_spin_sum import mms_hpca_spin_sum
+from pyspedas.mms.fpi.mms_fpi_make_errorflagbars import mms_fpi_make_errorflagbars
+from pyspedas.mms.fpi.mms_fpi_make_compressionlossbars import mms_fpi_make_compressionlossbars
 
 from pytplot import get_data, del_data
 
@@ -87,24 +89,6 @@ class FEEPSLoadTestCases(unittest.TestCase):
         self.assertTrue(data_exists('mms4_epd_feeps_brst_l2_electron_intensity_omni'))
         self.assertTrue(data_exists('mms4_epd_feeps_brst_l2_electron_intensity_omni_spin'))
 
-############### EIS ############### 
-class EISLoadTestCases(unittest.TestCase):
-    def test_load_phxtof_data(self):
-        data = mms_load_eis(trange=['2015-10-16', '2015-10-16/01:00'], datatype='phxtof')
-        self.assertTrue(data_exists('mms1_epd_eis_phxtof_proton_flux_omni'))
-
-    def test_load_phxtof_spdf(self):
-        data = mms_load_eis(trange=['2015-10-16/13:06', '2015-10-16/13:07'], datatype='phxtof', data_rate='brst', spdf=True)
-        self.assertTrue(data_exists('mms1_epd_eis_brst_phxtof_proton_flux_omni'))
-
-    def test_load_extof_data(self):
-        data = mms_load_eis(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='extof')
-        self.assertTrue(data_exists('mms1_epd_eis_brst_extof_proton_flux_omni'))
-
-    def test_load_extof_suffix(self):
-        data = mms_load_eis(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='extof', suffix='_test')
-        self.assertTrue(data_exists('mms1_epd_eis_brst_extof_proton_flux_omni_test'))
-
 ############### FPI ############### 
 class FPILoadTestCases(unittest.TestCase):
     def test_load_default_data(self):
@@ -119,6 +103,20 @@ class FPILoadTestCases(unittest.TestCase):
         data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype=['dis-moms', 'dis-dist'], time_clip=True)
         self.assertTrue(data_exists('mms1_dis_energyspectr_omni_brst'))
 
+    def test_load_rename_bars(self):
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='des-dist')
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='dis-dist')
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='des-moms')
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype='dis-moms')
+        self.assertTrue(data_exists('mms1_dis_compressionloss_brst_moms'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_moms'))
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_moms'))
+        self.assertTrue(data_exists('mms1_des_compressionloss_brst_moms'))
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_dist'))
+        self.assertTrue(data_exists('mms1_des_compressionloss_brst_dist'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_dist'))
+        self.assertTrue(data_exists('mms1_dis_compressionloss_brst_dist'))
+
     def test_center_fast_ion_data_notplot(self):
         data = mms_load_fpi(trange=['2015-10-16/14:00', '2015-10-16/15:00'], notplot=True)
         centered = mms_load_fpi(trange=['2015-10-16/14:00', '2015-10-16/15:00'], center_measurement=True, suffix='_centered', notplot=True)
@@ -157,6 +155,30 @@ class FPILoadTestCases(unittest.TestCase):
         c, d = get_data('mms1_des_bulkv_gse_brst_centered')
         self.assertTrue(np.round(c[0]-t[0], decimals=3) == 0.015)
 
+    def test_errorflag_compression_bars(self):
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype=['des-dist', 'des-moms'])
+        data = mms_load_fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'], data_rate='brst', datatype=['dis-dist', 'dis-moms'])
+        # mms_fpi_make_errorflagbars('mms1_des_errorflags_brst_moms', level='l2')
+        # mms_fpi_make_errorflagbars('mms1_dis_errorflags_brst_moms', level='l2')
+        # mms_fpi_make_errorflagbars('mms1_des_errorflags_brst_dist', level='l2')
+        # mms_fpi_make_errorflagbars('mms1_dis_errorflags_brst_dist', level='l2')
+        # mms_fpi_make_compressionlossbars('mms1_des_compressionloss_brst_moms')
+        # mms_fpi_make_compressionlossbars('mms1_dis_compressionloss_brst_moms')
+        # mms_fpi_make_compressionlossbars('mms1_des_compressionloss_brst_dist')
+        # mms_fpi_make_compressionlossbars('mms1_dis_compressionloss_brst_dist')
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_moms_flagbars_full'))
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_moms_flagbars_main'))
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_moms_flagbars_mini'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_moms_flagbars_full'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_moms_flagbars_main'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_moms_flagbars_mini'))
+        self.assertTrue(data_exists('mms1_des_errorflags_brst_dist_flagbars_dist'))
+        self.assertTrue(data_exists('mms1_dis_errorflags_brst_dist_flagbars_dist'))
+        self.assertTrue(data_exists('mms1_des_compressionloss_brst_moms_flagbars'))
+        self.assertTrue(data_exists('mms1_dis_compressionloss_brst_moms_flagbars'))
+        self.assertTrue(data_exists('mms1_des_compressionloss_brst_dist_flagbars'))
+        self.assertTrue(data_exists('mms1_dis_compressionloss_brst_dist_flagbars'))
+
 ############### HPCA ############### 
 class HPCALoadTestCases(unittest.TestCase):
     def test_load_default_data(self):
@@ -167,6 +189,13 @@ class HPCALoadTestCases(unittest.TestCase):
         data = mms_load_hpca(trange=['2015-10-16', '2015-10-16/01:00'], spdf=True)
         self.assertTrue(data_exists('mms1_hpca_hplus_number_density'))
 
+    def test_load_ion_omni_suffix(self):
+        del_data('*')
+        data = mms_load_hpca(probe=2, trange=['2016-08-09/09:10', '2016-08-09/10:10:00'], datatype='ion', data_rate='brst', suffix='_brst')
+        mms_hpca_calc_anodes(fov=[0, 360], probe=2, suffix='_brst')
+        mms_hpca_spin_sum(probe=2, suffix='_brst', avg=True)
+        self.assertTrue(data_exists('mms2_hpca_hplus_flux_brst_elev_0-360_spin'))
+
     def test_load_ion_omni(self):
         del_data('*')
         data = mms_load_hpca(trange=['2016-10-16/5:00', '2016-10-16/6:00'], datatype='ion')
@@ -263,6 +292,8 @@ class FGMLoadTestCases(unittest.TestCase):
     def test_load_default_data(self):
         data = mms_load_fgm(trange=['2015-10-16', '2015-10-16/01:00'])
         self.assertTrue(data_exists('mms1_fgm_b_gse_srvy_l2'))
+        self.assertTrue(data_exists('Epoch'))
+        self.assertTrue(data_exists('Epoch_state'))
 
     def test_load_spdf_data(self):
         data = mms_load_fgm(data_rate='brst', trange=['2015-10-16/13:06', '2015-10-16/13:10'], spdf=True)
