@@ -11,6 +11,8 @@ from .slice2d_nearest import slice2d_nearest
 from .slice2d_rlog import slice2d_rlog
 from .slice2d_s2c import slice2d_s2c
 from .slice2d_2di import slice2d_2di
+from .slice2d_smooth import slice2d_smooth
+from .slice2d_subtract import slice2d_subtract
 
 from pyspedas import time_double, time_string
 
@@ -29,6 +31,7 @@ def slice2d(dists,
             energy=False,
             log=False,
             erange=None,
+            smooth=None,
             thetarange=None,
             zdirrange=None,
             mag_data=None,
@@ -56,6 +59,8 @@ def slice2d(dists,
         return
 
     if interpolation == '2d':
+        if smooth is None:
+            smooth = 7
         if resolution is None:
             resolution = 150
         if thetarange is None and zdirrange is None:
@@ -168,6 +173,12 @@ def slice2d(dists,
 
     geo_shift = [0, 0, 0]
     if subtract_bulk:
+        vectors = slice2d_subtract(rot_matrix['vectors'], vbulk)
+
+        if vectors is not None:
+            rot_matrix['vectors'] = vectors
+
+        # the shift is applied later for geometric interpolation
         geo_shift = vbulk
 
     # sort transformed vector grid
@@ -185,6 +196,9 @@ def slice2d(dists,
     elif interpolation == '2d':
         the_slice = slice2d_2di(data['data'], rot_matrix['vectors'], resolution, thetarange=thetarange, zdirrange=zdirrange)
 
+    if smooth is not None:
+        the_slice = slice2d_smooth(the_slice, smooth)
+
     # Get metadata and return slice
     # ------------------------------------------------------------------------
     if energy:
