@@ -61,8 +61,8 @@ def download_file(url=None, filename=None, headers={}, username=None, password=N
     if session is None:
         session = requests.Session()
     
-    if username != None:
-        session.auth = (username, password)
+    if username is not None:
+        session.auth = requests.auth.HTTPDigestAuth(username, password)
 
     # check if the file exists, and if so, set the last modification time in the header
     # this allows you to avoid re-downloading files that haven't changed
@@ -73,7 +73,6 @@ def download_file(url=None, filename=None, headers={}, username=None, password=N
         warnings.simplefilter("ignore", category=ResourceWarning)
         fsrc = session.get(url, stream=True, verify=verify, headers=headers)
 
-
     # need to delete the If-Modified-Since header so it's not set in the dictionary in subsequent calls
     if headers.get('If-Modified-Since') != None:
         del headers['If-Modified-Since']
@@ -117,6 +116,7 @@ def download_file(url=None, filename=None, headers={}, username=None, password=N
 
     fsrc.close()
     ftmp.close()
+    os.unlink(ftmp.name) # delete the temporary file
     
     logging.info('Download complete: ' + filename)
 
