@@ -38,10 +38,14 @@ def time_float_one(s_time=None):
     if s_time is None:
         s_time = str(datetime.now())
 
-    if isinstance(s_time, (int, float, np.integer, np.float)):
+    if isinstance(s_time, (int, float, np.integer, np.float64)):
         return float(s_time)
 
-    in_datetime = parser.parse(s_time)
+    try:
+        in_datetime = parser.isoparse(s_time)
+    except ValueError:
+        in_datetime = parser.parse(s_time)
+
     float_time = in_datetime.replace(tzinfo=timezone.utc).timestamp()
 
     return float_time
